@@ -30,7 +30,7 @@ class XBRLElement:
     """
     def __init__(self, uri, label=None, value=None, ref=None):
         """Constructor Method"""
-        self.uri = uri
+        self.uri = uri.split("/")[-1]
         self.label = label
         self.ref = ref
         self.value = value
@@ -202,7 +202,7 @@ class XBRLAssembler:
     """
     uri_re = re.compile(r'(?:lab_)?((us-gaap|source|dei|[a-z]{3,4})[_:][A-Za-z]{5,})', re.IGNORECASE)
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, schema=None, label=None, data=None, ref=None, *args, **kwargs):
         logger.debug(f"Created Assembler (*args={args}, **kwargs={kwargs})")
 
         self.args = args
@@ -214,8 +214,26 @@ class XBRLAssembler:
         self.labels = {}
         self.cells = collections.defaultdict(list)
 
-        self.ref = None
+        self.ref = ref
 
+        if schema is not None:
+            self.parse_schema(schema)
+
+        if label is not None:
+            self.parse_labels(label)
+
+        if data is not None:
+            self.parse_cells(data)
+
+        for uri, ele in self.xbrl_elements.items():
+            if not ele.children:
+                try:
+                    self.__assemble(uri, ele)
+                except XBRLError as e:
+                    logger.debug(e)
+
+    def __repr__(self):
+        return f"XBRLAssembler ({list(self.xbrl_elements.keys())})"
 
     @classmethod
     def from_sec_index(cls, index_url, ref_doc=XBRLType.PRE, *args, **kwargs):
@@ -244,15 +262,12 @@ class XBRLAssembler:
             file_map[XBRLType.get(row[3].text)] = soup
 
         try:
-            xbrl_assembler = cls(*args, **kwargs)
-
             ref = next((ref for ref in [ref_doc, XBRLType.PRE, XBRLType.DEF, XBRLType.CALC] if ref in file_map))
-            xbrl_assembler.ref = file_map[ref]
-
-            xbrl_assembler.parse_schema(file_map[XBRLType.SCHEMA])
-            xbrl_assembler.parse_labels(file_map[XBRLType.LABEL])
-            xbrl_assembler.parse_cells(file_map[XBRLType.DATA])
-
+            xbrl_assembler = cls(schema=file_map[XBRLType.SCHEMA],
+                                 label=file_map[XBRLType.LABEL],
+                                 data=file_map[XBRLType.DATA],
+                                 ref=file_map[ref],
+                                 *args, **kwargs)
             return xbrl_assembler
         except KeyError:
             raise XBRLError(f"Could not find all document from {index_url}")
@@ -276,14 +291,12 @@ class XBRLAssembler:
                 file_map[XBRLType.get(item)] = BeautifulSoup(open(os.path.join(directory, item), 'r'), 'lxml')
 
         try:
-            xbrl_assembler = cls(*args, **kwargs)
-
             ref = next((ref for ref in [ref_doc, XBRLType.PRE, XBRLType.DEF, XBRLType.CALC] if ref in file_map))
-            xbrl_assembler.ref = file_map[ref]
-
-            xbrl_assembler.parse_schema(file_map[XBRLType.SCHEMA])
-            xbrl_assembler.parse_labels(file_map[XBRLType.LABEL])
-            xbrl_assembler.parse_cells(file_map[XBRLType.DATA])
+            xbrl_assembler = cls(schema=file_map[XBRLType.SCHEMA],
+                                 label=file_map[XBRLType.LABEL],
+                                 data=file_map[XBRLType.DATA],
+                                 ref=file_map[ref],
+                                 *args, **kwargs)
 
             return xbrl_assembler
         except KeyError:
@@ -320,21 +333,29 @@ class XBRLAssembler:
             if not isinstance(other, XBRLAssembler):
                 raise XBRLError(f"XBRLAssembler must merge with another XBRLAssembler not {type(other)}")
 
-            for uri, header_ele in self.xbrl_elements.items():
-                uri_prefix = uri.split('/')[-1]
-                uri_lookup = next((uri for uri in other.xbrl_elements.keys() if uri_prefix in uri), None)
-                if uri_lookup is None:
-                    logger.debug(f"Merge failed on document search (uri_prefix={uri_prefix})")
-                    continue
+            logger.debug(f"Merging {other}")
 
-                other_doc = other.xbrl_elements[uri_lookup]
+            for uri, header_ele in self.xbrl_elements.items():
+                if uri in other.xbrl_elements.keys():
+                    other_doc = other.xbrl_elements[uri]
+                else:
+                    search_check = lambda regex, ele: re.search(regex, ele.uri) or re.search(regex, ele.label)
+                    fin_stmt = next((stmt for stmt in FinancialStatement if search_check(stmt.value, header_ele)), None)
+                    if fin_stmt == FinancialStatement.NOTE:
+                        continue
+                    other_doc = other.get(fin_stmt) if fin_stmt is not None else other.get(header_ele.uri)
+
+                if other_doc is None:
+                    logger.debug(f"Merge failed on document search {uri}")
+                    continue
 
                 for other_ele in other_doc.data():
                     search_ele = header_ele.search(other_ele.uri)
                     if search_ele:
                         search_ele.merge(other_ele)
                     else:
-                        logger.debug(f"Merge failed on element search (header_ele={header_ele}, other_ele={other_ele})")
+                        logger.debug(f"Merge failed on element search (header_ele={header_ele.uri}, other_ele={other_ele})")
+
         return self
 
     def uri(self, raw):
@@ -396,19 +417,6 @@ class XBRLAssembler:
                               ref=node['contextref'])
             self.cells[uri].append(ele)
 
-    def get_all(self):
-        """
-        A shortcut command to parse all documents against the reference document
-        """
-        for ele in self.xbrl_elements.values():
-            if not ele.children:
-                try:
-                    self.__assemble(ele)
-                except XBRLError as e:
-                    logger.debug(e)
-
-        return self.xbrl_elements
-
     def get(self, search) -> XBRLElement:
         """
         Main access function that will take a variety of search criteria and attempt to create and
@@ -418,7 +426,7 @@ class XBRLAssembler:
 
         :return: class:`xbrlassembler.XBRLElement` for the top of a tree representing the requested document
         """
-        search_data = sorted(self.xbrl_elements.items(), key=lambda item: item[1].ref)
+        search_data = sorted(self.xbrl_elements.values(), key=lambda item: item.ref)
 
         if isinstance(search, re.Pattern) or isinstance(search, str):
             search_term = search
@@ -428,24 +436,17 @@ class XBRLAssembler:
             raise ValueError(f"XBRLAssembler.get() search term should be "
                              f"re.Pattern, string, or FinancialStatement not {search}")
 
-        doc_ele = next((ele for uri, ele in search_data if re.search(search_term, uri) or re.search(search_term, ele.label)))
-        if doc_ele is None:
-            raise XBRLError(f"No match found for {search} in names.\n\t"
-                            f"Names available {[name for name in self.xbrl_elements.keys()]}]")
+        doc_search = lambda term, ele: re.search(search_term, ele.uri) or re.search(search_term, ele.label)
+        return next((ele for ele in search_data if doc_search(search_term, ele)), None)
 
-        if not doc_ele.children:
-            self.__assemble(doc_ele)
-
-        return doc_ele
-
-    def __assemble(self, doc_ele):
+    def __assemble(self, uri, doc_ele):
         if self.ref is None:
             return
 
         # Find desired section in reference document
-        def_link = self.ref.find(re.compile(r'link', re.IGNORECASE), attrs={'xlink:role': doc_ele.uri})
+        def_link = self.ref.find(re.compile(r'link', re.IGNORECASE), attrs={'xlink:role': uri})
         if not def_link:
-            raise XBRLError(f"Refernce document doesn't contain any information for {doc_ele.uri}")
+            raise XBRLError(f"Refernce document doesn't contain any information for {uri}")
 
         # Pull all elements and create XBRLElements out of them
         eles = {}
